@@ -114,11 +114,11 @@ class TransactionID(Data):
 
     def __str__(self) -> str:
         clazz = self.__class__.__name__
-        return '<%s: %s />' % (clazz, self._buffer)
+        return '<%s: %s />' % (clazz, self.get_bytes())
 
     def __repr__(self) -> str:
         clazz = self.__class__.__name__
-        return '<%s: %s />' % (clazz, self._buffer)
+        return '<%s: %s />' % (clazz, self.get_bytes())
 
     @classmethod
     def parse(cls, data: Data):  # -> TransactionID
@@ -209,6 +209,8 @@ class Header(Data):
     MAX_BODY_LENGTH = 1024 * 1024 * 1024  # 1GB
     MAX_PAGES = 1024 * 1024 * 2           # 1GB
 
+    MAGIC_CODE = b'DIM'
+
     def __init__(self, data,
                  data_type: DataType, sn: TransactionID,
                  pages: int=1, offset: int=0, body_length: int=-1):
@@ -264,7 +266,7 @@ class Header(Data):
         return self.__type
 
     @property
-    def trans_id(self) -> TransactionID:
+    def sn(self) -> TransactionID:
         return self.__sn
 
     @property
@@ -286,7 +288,9 @@ class Header(Data):
         if data._length < 4:
             # raise AssertionError('package error: %s' % data)
             return None
-        if data._buffer[0:3] != b'DIM':
+        if data.get_byte(index=0) != cls.MAGIC_CODE[0] or \
+                data.get_byte(index=1) != cls.MAGIC_CODE[1] or \
+                data.get_byte(index=2) != cls.MAGIC_CODE[2]:
             # raise AssertionError('not a DIM package: %s' % data)
             return None
         # get header length & data type
@@ -369,7 +373,7 @@ class Header(Data):
         # generate header data
         hl_ty = (head_len << 2) | (data_type.value & 0x0F)
         data = MutableData(capacity=head_len)
-        data.append(b'DIM')
+        data.append(cls.MAGIC_CODE)  # b'DIM'
         data.append(hl_ty)
         if sn != TransactionID.ZERO:
             data.append(sn)
@@ -481,7 +485,7 @@ class Package(Data):
             fragments.append(body)
         # create packages with fragments
         data_type = MessageFragment
-        sn = head.trans_id
+        sn = head.sn
         packages = []
         if head.body_length < 0:
             # UDP (unlimited)
@@ -514,7 +518,7 @@ class Package(Data):
         assert count > 1, 'packages count error: %d' % count
         first = packages[0]
         assert isinstance(first, Package), 'first package error: %s' % first
-        sn = first.head.trans_id
+        trans_id = first.head.sn
         # get fragments count
         pages = first.head.pages
         assert pages == count, 'pages error: %d, %d' % (pages, count)
@@ -524,7 +528,7 @@ class Package(Data):
         for item in packages:
             assert isinstance(item, Package), 'package error: %s' % item
             assert item.head.data_type == MessageFragment, 'data type not fragment: %s' % item
-            assert item.head.trans_id == sn, 'transaction ID not match: %s' % item
+            assert item.head.sn == trans_id, 'transaction ID not match: %s' % item
             assert item.head.pages == pages, 'pages error: %s' % item
             assert item.head.offset == index, 'fragment missed: %d, %s' % (index, item)
             data += item.body.get_bytes()
@@ -538,4 +542,4 @@ class Package(Data):
         else:
             # TCP (should not happen)
             body_len = body.length
-        return cls.new(data_type=Message, sn=sn, body_length=body_len, body=body)
+        return cls.new(data_type=Message, sn=trans_id, body_length=body_len, body=body)
